Daring Fireball: The iPhone 16e
Description: The iPhone 16e is an iPhone for people who don’t want to think much about their phone. But they *do* want an iPhone, not just any “whatever” phone. A just plain iPhone, with a good screen, good enough (and simple) camera, and great battery life.

# The iPhone 16e

###### Wednesday, 26 February 2025

I’ve spent the last six days using the iPhone 16e, and the experience has been a throwback. In many ways, the iPhone 16e both looks and feels like the modern-day progeny of the early Steve Jobs era iPhones. Early iPhones like the plastic 3G and 3GS, and the glass-back/metal-sides 4 and 4S were simpler offerings. Two colors, black and white. Single-lens inconspicuous cameras. The iPhone 16e feels like their direct descendent.

Let’s start with the camera. With just a single lens on the back, the iPhone 16e camera doesn’t just look less conspicuous compared to its dual- and triple-lens brethren, it feels less conspicuous. Especially for me, coming from several years of daily-driving an iPhone Pro model, the 16e feels strikingly smaller in hand and pocket because it lacks the entire “mesa” protrusion from which iPhone 16 and 16 Pro camera lenses further protrude.

Apple’s tech specs for iPhone thickness don’t include the camera lenses or camera mesas. Apple just measures and reports the thickness of the flat non-camera part of the phone. But those camera modules and lenses protrude quite a bit. Using a digital caliper, I measured the thickness of the three “levels” of the 16e, regular 16, and 16 Pro:

| Base | Mesa | Lens(es)
iPhone 16e | 7.8mm | — | 9.5mm
iPhone 16 | 7.8mm | 9.6mm | 11.3mm
iPhone 16 Pro | 8.3mm | 10.3mm | 12.5mm

So not only does the 16e completely omit the mesa, but the thickness of the entire camera, from the lens to the front display, is less than the thickness of the iPhone 16 and iPhone 16 Pro at their mesas, not even including their lenses.

Just look at this screenshot from Apple’s comparison page, showing all three side-by-side in their black color options:

The iPhone 16e looks like a phone with a tiny camera on the back. The iPhone 16 Pro looks like a camera that also happens to be a phone. You can really feel the difference in hand, too — not just the weight, but the balance.1 You can feel that the 16 Pro’s extra camera hardware adds extra weight. Per Apple’s specs, the iPhone 16e weighs 167g; the 16 Pro 199g — a 16 percent difference. (Also take note of a clever touch: Apple’s default wallpapers for each phone subtly suggest how many camera lenses they have.)

The 16e camera lens is not flush with the back of the phone, but it protrudes so little (just 1.7mm by my measurement) that it harks back to when iPhone cameras first started jutting out from the back of the phones at all. The 16e still wobbles when laid on a tabletop, but dramatically less than a regular iPhone 16 or especially the iPhone 16 Pro, whose camera module seems downright bulbous in comparison. But the 16e’s 1.7mm camera lens protrusion is so minimal that, when put in a case, the phone does lay perfectly flat on a table, because the cases need no protective rim for the camera, because the 16e camera lens protrudes less than the thickness of the case. (Apple included two of its $39 Silicone Cases with my review kit, in blue and black. They’re fine, and feel exactly like Apple’s usual Silicone Cases.)

Because the “macro” mode on the recent regular and Pro iPhone models uses the 0.5× ultrawide camera, a secondary lens the 16e doesn’t have, the 16e doesn’t have a macro mode. Starting with the iPhone 13 Pro, macro mode has allowed iPhone Pros to focus on objects less than an inch away. But, because the 16e’s 1× camera has a smaller sensor and smaller lens than the 1× camera on more expensive iPhone models, it’s able to focus at shorter distances than those bigger and otherwise better 1× cameras. The 1× camera on an iPhone 16 Pro has a minimum focus distance of 24cm (~9.5 inches). The 1× camera on an iPhone 16e has a minimum focus distance of 12cm (~4.75 inches). Actual macro mode (on regular and Pro iPhone models) is better, but you don’t need it as much when the 16e’s lone camera can focus on objects at half the distance, just over 4 inches away, in its regular shooting mode.

The 16e’s inconspicuous camera comes with a price, of course: image quality. You can really see the difference in low light. The 16e camera is slower (resulting in blurry images with subjects in motion) and images are noisier. The difference is especially obvious when shooting in low light with Process Zero in Halide. It’s a fine camera though, for point-and-shoot purposes. For most people who might be considering the iPhone 16e, it’ll probably be the best camera they’ve ever owned. And there’s something to be said for the simplicity of just one lens, offering 1× and 2× fields of view. If you know what an ƒ-stop is, you probably shouldn’t buy an iPhone 16e. If you don’t know what an ƒ-stop is, you probably won’t notice any difference in camera quality from an iPhone 16 or even 16 Pro. It’s a perfect camera for anyone who just wants a decent camera.

## What’s Missing: MagSafe, ProMotion, and Ultra Wideband (and, uh, the Other Ultra Wideband)

Peruse Apple’s comparison page, comparing the 16e to the 16 Pro and regular 16, and you’ll spot dozens of small differences. But the one omission that grabbed the most attention (and generated the most “WTF Apple?” reactions) is MagSafe. I own a bunch of MagSafe peripherals, and personally would never want to buy an iPhone without it. I have a dock at my desk (great with StandBy mode), a charger at my nightstand, and convenient doodads like this magnetic folding stand. One week into using the 16e as my main phone, and I still miss MagSafe as much as I did the first night.

But according to Apple representatives, most people in the 16e’s target audience exclusively charge their phones by plugging them into a charging cable. They tend not to use inductive charging at all, and when they do, they might not care that the 16e is stuck with a pokey 7.5W Qi charging speed, when recent more expensive iPhones charge via MagSafe at 15W or even 25W. For me, it’s not the high charging speed I miss most; it’s the snapping into place.2 I think Apple knows the 16e’s intended audience better than I do. Daring Fireball readers aren’t in the 16e demographic; it’s the friends and family members of DF readers who are.

What features do typical low-end iPhone buyers care about? They want a phone that looks good, with a good display, a decent camera, and long battery life. Do they care that the 16e only supports Wi-Fi 6, not 7? No, because they have zero idea what Wi-Fi version numbers even mean. They just think Wi-Fi is Wi-Fi. Do they care about superspeed mmWave 5G networking from Verizon (a.k.a. “ultra wideband”)? No. They just want their cellular connection to be fast and strong. (My review unit from Apple came with a temporary eSIM on AT&T. Cellular connections were fast and strong all week. The only place where I noticed a weak signal was in a deeply suburban / borderline rural area while visiting family over the weekend; my wife’s iPhone 15 Pro Max lost its signal on Verizon at the same location. I have zero complaints about Apple’s C1 modem.)

The iPhone 16e also omits the other “ultra wideband”, the chip Apple uses for precise location detection — like tracking an AirPod to within a foot. Precision finding is super cool, and when you’re truly bedeviled by a lost item like a keychain, remarkably helpful. Ultra wideband has been included on all new iPhones other than the SE (and now 16e) since the iPhones 11 in 2019. From a nerd’s perspective, it really does seem like a curious omission from the 16e five years later. But how many people in your extended family know what “ultra wideband precision finding” is?

To date, only Apple’s iPhone Pro models have supported ProMotion — Apple’s marketing name for a display that features adaptive refresh rates that go up to 120 Hz and down to 1 Hz for the “Always On” display mode. Given that the regular iPhone 16 (and 16 Plus) don’t support ProMotion, there was zero chance the 16e would. There are mid-range Android phones with high-refresh-rate displays, but (a) I don’t think they’re better displays, all things considered, and (b) they’re mid-range Android phones. It’s like bragging about the refresh rate on the dashboard display in a Kia Sorento. The 16e display also sports a throwback notch in lieu of the fancier, more playful, and at times cleverly useful, dynamic island.

The iPhone 16e targets the “I only care about the basics” iPhone buyer: the screen looks good, the camera is good but simple, the battery lasts a long time (the difference should be quite striking for anyone upgrading from a four- or five-year-old iPhone), it runs all their existing apps, and it charges fast when plugged into a USB cable. Those are the basics, and the basics are all that casual users care about. That it’s lighter in weight and physically smaller thanks to its minimally protruding single camera lens is gravy.

## Pricing

The only aspect of the 16e garnering more discussion than its omission of MagSafe is its starting price of $600 for a 128 GB base model. “It should cost $100 less” say some people, who tend to be the same people who also strongly believe it should include MagSafe and a ProMotion display. Here’s Apple’s current iPhone lineup, plus the discontinued (but still available from some carriers) 3rd-generation SE:

iPhone | Chip | 64 GB | 128 GB | 256 GB | 512 GB | 1 TB
SE (3rd gen) | A15 | $430 | $480 | $580 | — | —
16e | A18 | — | $600 | $700 | $900 | —
15 | A16 | — | $700 | $800 | $1000 | —
16 | A18 | — | $800 | $900 | $1100 | —
16 Plus | A18 | — | $900 | $1000 | $1200 | —
16 Pro | A18 Pro | — | $1000 | $1100 | $1300 | $1500
16 Pro Max | A18 Pro | — | — | $1200 | $1400 | $1600

That’s a tidy pricing matrix with $100 increments. The new 16e starting at $600 makes more sense than the old SE starting at just $430. $600 is clearly the next logical “rung” under the year-old iPhone 15’s $700 starting price. Complaining that Apple no longer makes a phone that’s priced in the $400-500 range is like complaining that BMW no longer makes any cars that cost less than $40,000. They’re Apple. It’s an iPhone. Of course it costs more than a no-name Android phone, or the 27th model down the ladder in Samsung’s sprawling product lineup. Anyone who wants to spend less than $600 for an iPhone can buy one from the flourishing pre-owned/refurbished market — just like buying a BMW for under $40,000.

The iPhone 16e is an iPhone for people who don’t want to think much about their phone. But they do want an iPhone, not just any “whatever” phone. A just plain iPhone, with a good screen, good enough (and simple) camera, and great battery life. I think Apple nailed that with the iPhone 16e.

1. There’s a decided feel difference with the side rails of the 16e too. The sides feel sharper, less rounded, than the regular 16 and 16 Pro (and the 15/15 Pro, and 14/14 Pro ...). That squareness (sharp-cornered-ness?) isn’t bad, per se, but it does subtly convey a sense of the 16e being a less premium device. ↩︎

2. One of the most surprising aspects of my professional life in recent years is how much time I spend thinking and writing about magnets. But the “snapping into place” thing does raise the question of why Apple didn’t include magnets in its cases for the 16e. ↩︎

Previous: | Apple Pulls Advanced Data Protection From the UK, in Defiance of UK Demand for Global Backdoor
Next: | Why Can’t We Screenshot Frames From DRM-Protected Video on Apple Devices?